@@ -6,7 +6,7 @@ an entirely independent project.
 
 It makes use of the JSON interface to Randall's site to retrieve comic data.
 
-One can create comic objects manually using Comic(number), or can use the 
+One can create comic objects manually using Comic(number), or can use the
 helper functions provided- getLatestComic(), getRandomComic(), and
 getComic()- to do this. Once you have a Comic object, you can access data
 from it using various provided methods."""
@@ -14,29 +14,49 @@ from it using various provided methods."""
 import json
 import os
 import random
-import urllib2 as urllib
+import sys
 import webbrowser
 
+# Python 3 support!
+if sys.version_info[0] <= 2:
+	import urllib2 as urllib
+else:
+	# This is kind of broken but I'm not sure of a better way.
+	import urllib.request as urllib
+
+# Define the URLs as globals.
+xkcdUrl = "http://www.xkcd.com/"			# The URL for xkcd.
+imageUrl = "http://imgs.xkcd.com/comics/"	# The root URL for image retrieval.
+explanationUrl = "http://explainxkcd.com/"	# The URL of the explanation.
+
 class Comic:
 	
 	def __init__(self, number):
+		global xkcdUrl, imageUrl
 		self.number = number
 		if number <= 0:
 			self.link = "Invalid comic"
 			return
-		self.link = "http://www.xkcd.com/" + str(number)
+		self.link = xkcdUrl + str(number)
 		
 		#Get data from the JSON interface
 		jsonString = self.link + "/info.0.json"
 		xkcd = urllib.urlopen(jsonString).read()
-		xkcdData = json.loads(xkcd)
+		xkcdData = json.loads(xkcd.decode())
 		self.title = xkcdData['safe_title'].encode('ascii')
 		self.altText = xkcdData['alt'].encode('ascii')
 		self.imageLink = xkcdData['img'].encode('ascii')
 		
+		# If this is Python 3, these are binary strings because we encoded them into ASCII
+		# ...so that urllib would be happy.
+		if sys.version_info[0] >= 3:
+			self.title = str(self.title, encoding='UTF-8')
+			self.altText = str(self.altText, encoding='UTF-8')
+			self.imageLink = str(self.imageLink, encoding='UTF-8')
+
 		#Get the image filename
-		offset = len('http://imgs.xkcd.com/comics/')
-		index = self.imageLink.find('http://imgs.xkcd.com/comics/')
+		offset = len(imageUrl)
+		index = self.imageLink.find(imageUrl)
 		self.imageName = self.imageLink[index + offset:]
 		
 	def __str__(self):
@@ -60,6 +80,11 @@ class Comic:
 	def getImageName(self):
 		"""Returns the name of the comic's image"""
 		return self.imageName
+
+	def getExplanation(self):
+		"""Returns an explain xkcd link for the comic."""
+		global explanationUrl
+		return explanationUrl + str(self.number)
 	
 	def show(self):
 		"""Uses the webbrowser module to open the comic"""
@@ -81,7 +106,7 @@ class Comic:
 		try:
 			download = open(output, 'wb')
 		except:
-			print "Unable to make file " + output
+			print("Unable to make file " + output)
 			return ""
 		download.write(image)
 		download.close()
@@ -90,7 +115,7 @@ class Comic:
 def getLatestComicNum():
 	"""Function to return the number of the latest comic."""
 	xkcd = urllib.urlopen("http://xkcd.com/info.0.json").read()
-	xkcdJSON = json.loads(xkcd)
+	xkcdJSON = json.loads(xkcd.decode())
 	number = xkcdJSON['num']
 	return number
 	
@@ -110,6 +135,6 @@ def getComic(number):
 	"""Function to return a Comic object for a given comic number"""
 	numComics = getLatestComicNum()
 	if number > numComics or number <= 0:
-		print "Error: You have requested an invalid comic."
+		print("Error: You have requested an invalid comic.")
 		return Comic(-1)
-	return ComiC(number)
+	return Comic(number)
